import java.util.Date;
import java.util.Calendar;
import java.text.*;

/***************   C l a s s :    S t o p W a t c h   ***************************
 * StopWatch implements a simple stop watch as one would use it in real life.	*
 ********************************************************************************/

import de.hamster.debugger.model.Territorium;import de.hamster.debugger.model.Territory;import de.hamster.model.HamsterException;import de.hamster.model.HamsterInitialisierungsException;import de.hamster.model.HamsterNichtInitialisiertException;import de.hamster.model.KachelLeerException;import de.hamster.model.MauerDaException;import de.hamster.model.MaulLeerException;import de.hamster.model.MouthEmptyException;import de.hamster.model.WallInFrontException;import de.hamster.model.TileEmptyException;import de.hamster.debugger.model.Hamster;public class StopWatch {

	private long startTime = 0;
	private long stopTime = 0;
	private boolean running = false;


	/* ------- public functions ------------------------------------------------*/
	
	// start() starts the stopwatch where ever it was stopped before.
	// If it is currently running, start() resets it to 0, and it keeps it running.
	public void start() {
		if (this.running) {
			this.startTime = System.currentTimeMillis();
		} else {
			this.startTime = System.currentTimeMillis() - getTime();
			this.running = true;
		}
	}

	// stop() stops the stopwatch, as you would do on a real stopwatch.
	// If it is already stopped, nothing happens.
	public void stop() {
		if (this.running) {
			this.stopTime = System.currentTimeMillis();
			this.running = false;
		}
	}

	// reset() resets the stopwatch to 0, without changing the running
	// state, i.e. if it was running, it continues running from 0.
	public void reset() {
		this.startTime = System.currentTimeMillis();
		this.stopTime = this.startTime;
	}


	// getTime() returns the elaspsed time in milliseconds.
	public long getTime() {
		long elapsed;
		if (running) {
			elapsed = (System.currentTimeMillis() - startTime);
		} else {
			elapsed = (stopTime - startTime);
		}
		return elapsed;
	}


	// getTimeSecs() returns the elaspsed time in seconds.
	public long getTimeSecs() {
		long elapsed;
		if (running) {
			elapsed = ((System.currentTimeMillis() - startTime) / 1000);
		} else {
			elapsed = ((stopTime - startTime) / 1000);
		}
		return elapsed;
	}

	// getTimeSecs() returns the elaspsed time as a mm:ss formatted string.
	// after 59:59 it starts with 00:00 again.
	public String getTimeMS() {
		Date date = new Date(getTime());
		DateFormat formatter = new SimpleDateFormat("mm:ss");
		return formatter.format(date);
	}
} // StopWatch
